pub struct MigrationReport {
pub source: MigrationReportSource,
pub target: PathBuf,
pub migrated: MigratedCounts,
pub skipped: Vec<MigrationEntry>,
pub warnings: Vec<MigrationEntry>,
pub cookies: Vec<BrowserCookie>,
}Expand description
The full result of migrate_profile, including the cookies to seed.
Fields
source: MigrationReportSourcetarget: PathBufTarget profile directory.
migrated: MigratedCountsskipped: Vec<MigrationEntry>warnings: Vec<MigrationEntry>Cookies read from the source, to seed over CDP (not written to disk).
Implementations
Sourceimpl MigrationReport
impl MigrationReport
Sourcepub fn into_parts(self) -> (Vec<BrowserCookie>, MigrationSummary)
pub fn into_parts(self) -> (Vec<BrowserCookie>, MigrationSummary)
Split the report into its cookies and the cookie-free summary.