pub fn classify_differences(
differences: &[ProbeDifference],
context: &ParityContext,
) -> (Vec<ParityDifference>, Vec<ParityDifference>)Expand description
Tag differences using the shared catalogue and return the unexplained subset.
pub fn classify_differences(
differences: &[ProbeDifference],
context: &ParityContext,
) -> (Vec<ParityDifference>, Vec<ParityDifference>)Tag differences using the shared catalogue and return the unexplained subset.