pub fn compare_command_lines(
reference: &str,
candidate: &str,
) -> CommandLineComparisonExpand description
Compare reported switch presence and values, including engine feature lists.
pub fn compare_command_lines(
reference: &str,
candidate: &str,
) -> CommandLineComparisonCompare reported switch presence and values, including engine feature lists.