pub struct ParityContext {
pub launch: String,
pub attached: bool,
pub extra_switches: Vec<String>,
pub requested_args: Vec<String>,
}Expand description
Context used to explain probe differences without hiding unknown changes.
Fields
launch: Stringreal or engine launch.
attached: boolWhether the measured browser was started by somebody else.
extra_switches: Vec<String>Extra switches reported by the browser.
requested_args: Vec<String>Arguments explicitly requested by the caller.