pub enum Locator<'a> {
Css(&'a str),
Id(&'a str),
LinkText(&'a str),
XPath(&'a str),
}Expand description
An element locator.
See the specification for more details.
Variants
Css(&'a str)
Find an element matching the given CSS selector.
Id(&'a str)
Find an element using the given id.
LinkText(&'a str)
Find a link element with the given link text.
The text matching is exact.
XPath(&'a str)
Find an element using the given XPath expression.
You can address pretty much any element this way, if you’re willing to put in the time to find the right XPath.