launch_webdriver_snapshot

Function launch_webdriver_snapshot 

pub async fn launch_webdriver_snapshot(
    source: SnapshotOptions,
    options: WebDriverOptions,
) -> Result<WebDriverSnapshotResult>
Copy a live Chromium profile and launch it through native Fantoccini. Firefox uses a different profile format and cannot consume Chromium copies.