pub struct DialogEvent {
pub dialog_type: DialogType,
pub message: String,
pub default_value: Option<String>,
}Expand description
Information about a dialog event.
This struct is passed to dialog handlers and contains all relevant information about the dialog that was triggered.
Fields
dialog_type: DialogTypeThe type of dialog.
message: StringThe message shown in the dialog.
default_value: Option<String>Default value for prompt dialogs.
Implementations
Sourceimpl DialogEvent
impl DialogEvent