is_timeout_error

Function is_timeout_error 

pub fn is_timeout_error(error_message: &str) -> bool
Check if an error message indicates a timeout error.

Arguments

  • error_message - The error message to check

Returns

true if the error appears to be a timeout error