Element visibility utilities.
This module provides utilities for checking element visibility and viewport positioning.
Structs
- Visibility
Options - Options for checking element visibility.
- Visibility
Result - Result of a visibility check.
Functions
- count
- Count the number of elements matching a selector.
- is_
enabled - Check if an element is enabled (for form elements).
- is_
in_ viewport - Calculate if an element is within the viewport.
- is_
visible - Check if an element is visible using the provided engine adapter.
- needs_
scrolling - Calculate if scrolling is needed to center an element.