Function init_logger
Source pub fn init_logger(options: LoggerOptions)
Initialize the global tracing subscriber with the given options.
This should be called once at the start of the application.
Arguments
options - Logger configuration options
Example
use browser_commander::core::logger::{init_logger, LoggerOptions};
init_logger(LoggerOptions { verbose: true });