Module visibility

Module visibility 

Element visibility utilities.

This module provides utilities for checking element visibility and viewport positioning.

Structs

VisibilityOptions
Options for checking element visibility.
VisibilityResult
Result of a visibility check.

Functions

count
Count the number of elements matching a selector.
is_enabled
Check if an element is enabled (for form elements).
is_in_viewport
Calculate if an element is within the viewport.
is_visible
Check if an element is visible using the provided engine adapter.
needs_scrolling
Calculate if scrolling is needed to center an element.